@@ -227,6 +227,34 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.coupon.presentCouponWithTemplateIdV2", {"presentWithTemplateModel": present_with_template_model})
 
+    def batch_create(self, request):
+        """
+        批量创建商品活动
+        :param request:批量创建活动请求参数
+        """
+        return self.__client.call("eleme.activity.play.batchCreate", {"request": request})
+
+    def batch_update(self, request):
+        """
+        批量更新商品活动
+        :param request:批量更新活动参数
+        """
+        return self.__client.call("eleme.activity.play.batchUpdate", {"request": request})
+
+    def batch_offline(self, request):
+        """
+        批量下线商品活动
+        :param request:批量下线活动
+        """
+        return self.__client.call("eleme.activity.play.batchOffline", {"request": request})
+
+    def batch_search(self, request):
+        """
+        批量查询商品活动列表
+        :param request:批量查询活动列表
+        """
+        return self.__client.call("eleme.activity.play.batchSearch", {"request": request})
+
     def query_order_subsidy(self, order_id):
         """
         查询订单内营销相关数据
@@ -234,6 +262,55 @@ class ActivityService:
         """
         return self.__client.call("eleme.activity.marketing.queryOrderSubsidy", {"orderId": order_id})
 
+    def create_campaign_dy_channel(self, request):
+        """
+        抖音创建招商活动后调用，创建e侧抖音频道
+        :param request:创建e侧抖音频道
+        """
+        return self.__client.call("eleme.activity.dy.createCampaignDyChannel", {"request": request})
+
+    def audit_status_call_back(self, request):
+        """
+        抖音审核状态回调
+        :param request:抖音审核状态回调
+        """
+        return self.__client.call("eleme.activity.dy.auditStatusCallBack", {"request": request})
+
+    def query_ele_apply_status(self, request):
+        """
+        抖音查询e侧报名单状态，用于核对状态一致性
+        :param request:查询e侧报名单状态
+        """
+        return self.__client.call("eleme.activity.dy.queryEleApplyStatus", {"request": request})
+
+    def offline_sku_apply(self, request):
+        """
+        抖音侧商品退出报名时调用，e侧商品退出报名
+        :param request:商品退出报名
+        """
+        return self.__client.call("eleme.activity.dy.offlineSkuApply", {"request": request})
+
+    def create_coupon_activity(self, request):
+        """
+        抖音侧创建券活动时调用
+        :param request:抖音创建券活动
+        """
+        return self.__client.call("eleme.activity.dy.createCouponActivity", {"request": request})
+
+    def modify_coupon_activity(self, request):
+        """
+        抖音侧修改券活动时调用
+        :param request:抖音创建券活动
+        """
+        return self.__client.call("eleme.activity.dy.modifyCouponActivity", {"request": request})
+
+    def query_dy_coupon_activity(self, request):
+        """
+        根据dy券活动id查询券活动信息
+        :param request:抖音查询券活动信息
+        """
+        return self.__client.call("eleme.activity.dy.queryDyCouponActivity", {"request": request})
+
     def create_and_participate_chain_price_activity(self, activity, chain_id, shop_apply_info):
         """
         创建并绑定连锁店特价活动
