@@ -37,3 +37,10 @@ class AllianceService:
         """
         return self.__client.call("eleme.alliance.queryOrderInfo", {"channelOrderQueryRequest": channel_order_query_request})
 
+    def query_institution_bill(self, query_institution_bill_request):
+        """
+        查询机构账单
+        :param queryInstitutionBillRequest:机构账单查询
+        """
+        return self.__client.call("eleme.alliance.queryInstitutionBill", {"queryInstitutionBillRequest": query_institution_bill_request})
+
