@@ -187,3 +187,26 @@ class FinanceService:
         """
         return self.__client.call("eleme.finance.queryInsuranceBillsByOrder", {"orderBillQuery": order_bill_query})
 
+    def page_query_chain_shop_agent_commission_bills(self, page_query):
+        """
+        分页查询总店代运营账单
+        :param pageQuery:总店账单分页查询条件
+        """
+        return self.__client.call("eleme.finance.pageQueryChainShopAgentCommissionBills", {"pageQuery": page_query})
+
+    def page_query_branch_shop_agent_commission_bills(self, page_query):
+        """
+        分页查询单店代运营账单
+        :param pageQuery:分页查询条件
+        """
+        return self.__client.call("eleme.finance.pageQueryBranchShopAgentCommissionBills", {"pageQuery": page_query})
+
+    def query_agent_commission_bills_by_order(self, order_bill_query):
+        """
+        查询外卖订单代运营账单
+ 根据订单ID查询
+ 一笔订单可能有多个代运营账单，存在正常单和退单
+        :param orderBillQuery:外卖订单查询条件
+        """
+        return self.__client.call("eleme.finance.queryAgentCommissionBillsByOrder", {"orderBillQuery": order_bill_query})
+
