@@ -18,7 +18,7 @@ class MsgnewService:
 
     def confirm_pull_msg(self, msg_confirm_request):
         """
-        向平台确认已成功拉取推送失败的消息
+        ISV通过该接口向平台确认已成功拉取消息
         :param msgConfirmRequest:查询条件
         """
         return self.__client.call("eleme.msgNew.confirmPullMsg", {"msgConfirmRequest": msg_confirm_request})
