@@ -377,3 +377,17 @@ class OrderService:
         """
         return self.__client.call("eleme.order.batchGetOrderAddress", {"orderIds": order_ids})
 
+    def query_refund_food_infos(self, order_id):
+        """
+        查询订单退款商品明细
+        :param orderId:订单Id
+        """
+        return self.__client.call("eleme.order.queryRefundFoodInfos", {"orderId": order_id})
+
+    def query_self_delivery_on_time_rate(self, shop_id):
+        """
+        查询自配送店铺送达准时率信息
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.order.querySelfDeliveryOnTimeRate", {"shopId": shop_id})
+
