@@ -1125,6 +1125,14 @@ class ProductService:
         """
         return self.__client.call("eleme.product.itemV2.batchUpdateAttributeSaleStatusByExtCode", {"shopId": shop_id, "updateAttributeSaleStatusRequests": update_attribute_sale_status_requests})
 
+    def batch_update_item_ingredient_sale_status_by_ext_code(self, shop_id, update_ingredient_sale_status_by_ext_code_requests):
+        """
+        根据商品extCode批量修改商品售卖属性状态
+        :param shopId:店铺Id
+        :param updateIngredientSaleStatusByExtCodeRequests:更新商品售卖属性请求列表，最大长度30
+        """
+        return self.__client.call("eleme.product.itemV2.batchUpdateItemIngredientSaleStatusByExtCode", {"shopId": shop_id, "updateIngredientSaleStatusByExtCodeRequests": update_ingredient_sale_status_by_ext_code_requests})
+
     def publish_spu(self, shop_id, spu, is_auto_sync):
         """
         发布一个品牌标品
