@@ -39,14 +39,33 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.mgetShopStatus", {"shopIds": shop_ids})
 
-    def set_delivery_time(self, shop_id, delivery_basic_mins, delivery_adjust_mins):
+    def set_delivery_time(self, shop_id, delivery_basic_mins, delivery_adjust_mins, special_delivery_time, distance_plus_time):
         """
         设置送达时间
         :param shopId:店铺Id
         :param deliveryBasicMins:配送基准时间(单位分钟)
         :param deliveryAdjustMins:配送调整时间(单位分钟)
+        :param specialDeliveryTime:特殊时段配送时间(单位分钟)
+        :param distancePlusTime:3km以上每km增加的时间(单位分钟)
         """
-        return self.__client.call("eleme.shop.setDeliveryTime", {"shopId": shop_id, "deliveryBasicMins": delivery_basic_mins, "deliveryAdjustMins": delivery_adjust_mins})
+        return self.__client.call("eleme.shop.setDeliveryTime", {"shopId": shop_id, "deliveryBasicMins": delivery_basic_mins, "deliveryAdjustMins": delivery_adjust_mins, "specialDeliveryTime": special_delivery_time, "distancePlusTime": distance_plus_time})
+
+    def set_self_shop_delivery_time(self, shop_id, delivery_time, special_delivery_time, distance_plus_time):
+        """
+        自配送商家设置送达时间
+        :param shopId:店铺Id
+        :param deliveryTime:配送总时间(单位:分钟)
+        :param specialDeliveryTime: 特殊时段配送时间(单位分钟)
+        :param distancePlusTime:3km以上每km增加的时间(单位分钟)
+        """
+        return self.__client.call("eleme.shop.setSelfShopDeliveryTime", {"shopId": shop_id, "deliveryTime": delivery_time, "specialDeliveryTime": special_delivery_time, "distancePlusTime": distance_plus_time})
+
+    def get_recommend_delivery_time(self, shop_id):
+        """
+        查询自配送推荐送达时间
+        :param shopId:店铺Id
+        """
+        return self.__client.call("eleme.shop.getRecommendDeliveryTime", {"shopId": shop_id})
 
     def set_online_refund(self, shop_id, enable):
         """
@@ -103,13 +122,15 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.getProductSubsidyLimit", {"shopId": shop_id})
 
-    def set_shop_t_model(self, shop_id, delivery_time):
+    def set_shop_t_model(self, shop_id, delivery_time, special_delivery_time, distance_plus_time):
         """
         设置店铺T模型
         :param shopId:店铺Id
         :param deliveryTime:配送总时间(单位:分钟)
+        :param specialDeliveryTime: 特殊时段配送时间(单位分钟)
+        :param distancePlusTime:3km以上每km增加的时间(单位分钟)
         """
-        return self.__client.call("eleme.shop.setShopTModel", {"shopId": shop_id, "deliveryTime": delivery_time})
+        return self.__client.call("eleme.shop.setShopTModel", {"shopId": shop_id, "deliveryTime": delivery_time, "specialDeliveryTime": special_delivery_time, "distancePlusTime": distance_plus_time})
 
     def set_shop_vocations(self, shop_id, vocation_dates, enabled):
         """
@@ -212,3 +233,31 @@ class ShopService:
         """
         return self.__client.call("eleme.shop.video.setVideoStatus", {"videoDeviceDTO": video_device_d_t_o})
 
+    def validate_shop_video_status(self, license_no):
+        """
+        (仅电信用,现已废弃)根据统一社会信用代码查询在饿了么侧是否已开店
+        :param licenseNo:统一社会信用代码
+        """
+        return self.__client.call("eleme.shop.video.validateShopVideoStatus", {"licenseNo": license_no})
+
+    def validate_shop_video_status_new(self, license_check_d_t_o):
+        """
+        根据统一社会信用代码查询在饿了么侧是否已开店
+        :param licenseCheckDTO:设备商及统一社会信用代码
+        """
+        return self.__client.call("eleme.shop.video.validateShopVideoStatusNew", {"licenseCheckDTO": license_check_d_t_o})
+
+    def sync_shop_video_devices(self, license_device_info):
+        """
+        第三方服务商同步设备信息
+        :param licenseDeviceInfo:设备信息
+        """
+        return self.__client.call("eleme.shop.video.syncShopVideoDevices", {"licenseDeviceInfo": license_device_info})
+
+    def sync_shop_ai_recognition_result(self, shop_ai_recognition):
+        """
+        第三方服务商同步AI识别结果
+        :param shopAiRecognition:AI识别结果
+        """
+        return self.__client.call("eleme.shop.video.syncShopAiRecognitionResult", {"shopAiRecognition": shop_ai_recognition})
+
